#
# spec file for package python-opencensus-ext-azure
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define repo_version 0.11.0
%if 0%{?suse_version} >= 1500
# mirror python-azure-core
%define skip_python2 1
%bcond_with python2
%else
%bcond_with python2
%endif
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-opencensus-ext-azure
Version:        1.1.6
Release:        1.5
Summary:        OpenCensus Azure Monitor Exporters
License:        Apache-2.0
URL:            https://github.com/census-instrumentation/opencensus-python
Source:         https://github.com/census-instrumentation/opencensus-python/archive/v%{repo_version}.tar.gz#/opencensus-%{repo_version}.tar.gz
# PATCH-FIX-UPSTREAM opencensus-pr1002-remove-mock.patch -- gh#census-instrumentation/opencensus-python#1002
Patch0:         opencensus-pr1002-remove-mock.patch
BuildRequires:  %{python_module azure-core >= 1.12.0}
BuildRequires:  %{python_module azure-identity >= 1.5.0}
BuildRequires:  %{python_module opencensus >= 0.11.0}
BuildRequires:  %{python_module psutil >= 5.6.3}
BuildRequires:  %{python_module requests >= 2.19.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with python2}
BuildRequires:  python-mock
BuildRequires:  python-unittest2
%endif
BuildArch:      noarch
Requires:       python-azure-core >= 1.12.0
Requires:       python-azure-identity >= 1.5.0
Requires:       python-opencensus >= 0.11.0
Requires:       python-psutil >= 5.6.3
Requires:       python-requests >= 2.19.0
%python_subpackages

%description
OpenCensus Azure Monitor Exporters

%prep
%setup -q -n opencensus-python-%{repo_version}/contrib/opencensus-ext-azure
pushd ../..
%patch0 -p1
popd
# for discovery to work
touch tests/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/opencensus/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/opencensus/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/opencensus/common/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/opencensus/common/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/opencensus/ext/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/opencensus/ext/__pycache__
}

%check
%python_exec -m unittest discover -v

%files %{python_files}
%doc CHANGELOG.md README.rst
%license ../../LICENSE
%dir %{python_sitelib}/opencensus
%dir %{python_sitelib}/opencensus/ext
%{python_sitelib}/opencensus/ext/azure
%{python_sitelib}/opencensus_ext_azure-%{version}*-info

%changelog
* Tue Oct 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.1.6
  * Add statusCode and exceptionType to network statsbeat (#1138)
- from version 1.1.5
  * Allow specifying metrics (custom_measurements) for Azure custom events (#1117)
  * Shutdown Statsbeat when hitting error/exception threshold (#1127)
  * Fix failure counting statsbeat - refactor status code logic in transport (#1132)
  * Use logging handler close instead of custom atexit hook (#1134)
- from version 1.1.4
  * Statsbeat bug fixes - status codes (#1113)
  * Statsbeat bug fixes - do not log if statsbeat (#1116)
  * Add deprecation warning for explicitly using instrumentation key (#1118)
- from version 1.1.3
  * Hotfix for version number (#1108)
- from version 1.1.2
  * Statsbeat bug fixes, shorten host in network stats (#1100)
  * Support statsbeat in EU regions (#1105)
- from version 1.1.1
  * Fix statsbeats metric names (#1089)
  * Add AAD statsbeat feature, fix incorrect counting of retry (#1093)
- Refresh patches for new version
  * opencensus-pr1002-remove-mock.patch
- Update BuildRequires and Requires from setup.py
* Sat Oct 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.1.0
  * Enable AAD authorization via TokenCredential (#1021)
  * Implement attach rate metrics via Statsbeat (#1053)
  * Implement network metrics via Statsbeat - Success count (#1059)
  * Implement network metrics via Statsbeat - Others (#1062)
  * Implement feature and instrumentation metrics via Statsbeat
    (#1076)
  * Support stamp specific redirect in exporters (#1078)
- Release 1.0.8
  * Fix logger.exception with no exception info throwing error
    (#1006)
  * Add enable_local_storage to turn on/off local storage + retry +
    flushing logic (#1016)
- Release 1.0.7
  * Hotfix (#1004)
- Release 1.0.6
  * Disable heartbeat metrics in exporters (#984)
  * Loosen instrumentation key validation to GUID (#986)
- Release 1.0.5
  * Attach rate metrics via Heartbeat for Web and Function apps
    (#930)
  * Attach rate metrics for VM (#935)
  * Add links in properties for trace exporter envelopes (#936)
  * Fix attach rate metrics for VM to only ping data service on
    retry (#946)
  * Added queue capacity configuration for exporters (#949)
- Release 1.0.4
  * Remove dependency rate from standard metrics (#903)
  * Implement customEvents using AzureEventHandler (#925)
- Release 1.0.3
  * Change default path of local storage (#903)
  * Add support to initialize azure exporters with proxies (#902)
- Remove mock
  * opencensus-pr1002-remove-mock.patch
  * gh#census-instrumentation/opencensus-python#1002
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Avoid extensions namespace clash
* Fri Feb 21 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.0.2
